Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(108)

Unified Diff: src/compiler/interpreter-assembler.h

Issue 1257543003: [Interpreter] Add more bytecode definitions and add operand types. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Rebase. Created 5 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/compiler/interpreter-assembler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/interpreter-assembler.h
diff --git a/src/compiler/interpreter-assembler.h b/src/compiler/interpreter-assembler.h
index b7ea4385f87d281e4d786e1d47ff848900a11eab..ead7b92d7aa8b6792398e0308ece8cdf844c4f7b 100644
--- a/src/compiler/interpreter-assembler.h
+++ b/src/compiler/interpreter-assembler.h
@@ -43,8 +43,8 @@ class InterpreterAssembler {
Node* NumberConstant(double value);
Node* HeapConstant(Unique<HeapObject> object);
- // Returns the bytecode argument |index| for the current bytecode.
- Node* BytecodeArg(int index);
+ // Returns the bytecode operand |index| for the current bytecode.
+ Node* BytecodeOperand(int index);
// Loads from and stores to the interpreter register file.
Node* LoadRegister(int index);
« no previous file with comments | « no previous file | src/compiler/interpreter-assembler.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698